@@ -4,6 +4,8 @@ from typing import TYPE_CHECKING, Optional
 
 from zeroconf import ServiceInfo
 
+from sila2.framework.utils import resolve_host_to_ip_addresses
+
 if TYPE_CHECKING:
     from sila2.server.sila_server import SilaServer
 
@@ -11,7 +13,7 @@ if TYPE_CHECKING:
 class SilaServiceInfo(ServiceInfo):
     sila_server: SilaServer
 
-    def __init__(self, server: SilaServer, address: str, port: int, ca: Optional[bytes] = None):
+    def __init__(self, server: SilaServer, host: str, port: int, ca: Optional[bytes] = None):
         properties = dict(
             version=server.server_version,
             server_name=server.server_name,
@@ -19,20 +21,17 @@ class SilaServiceInfo(ServiceInfo):
         )
 
         if ca is not None:
-            current_ca_pos = 0
-            current_line_num = 0
-            while current_ca_pos < len(ca):
-                key = f"ca{current_line_num}"
-                current_line_num += 1
+            properties.update({f"ca{i}": line for i, line in enumerate(ca.splitlines(keepends=False))})
 
-                value_length = 255 - len(key) - 1  # TXT records have max length 255 and are formatted as "key=value"
-                properties[key] = ca[current_ca_pos : current_ca_pos + value_length]
-                current_ca_pos += value_length
+        # ensure other devices don't try to connect via their localhost
+        ip_addresses = resolve_host_to_ip_addresses(host)
+        if len(ip_addresses) > 1 and "127.0.0.1" in ip_addresses:
+            ip_addresses.remove("127.0.0.1")
 
         super().__init__(
             type_="_sila._tcp.local.",
             name=f"{server.server_uuid}._sila._tcp.local.",
-            parsed_addresses=[address],
+            parsed_addresses=ip_addresses,
             port=port,
             properties=properties,
         )
