@@ -1,20 +1,15 @@
 from __future__ import annotations
 
 from datetime import timedelta
-from typing import TYPE_CHECKING, Optional, Type
+from typing import Optional
 
 from sila2.framework.abc.message_mappable import MessageMappable
 from sila2.framework.abc.named_data_node import NamedDataNode
-
-if TYPE_CHECKING:
-    from sila2.pb2_stubs import SiLAFramework_pb2
-    from sila2.pb2_stubs.SiLAFramework_pb2 import Duration as SilaDuration
+from sila2.framework.pb2 import SiLAFramework_pb2
+from sila2.framework.pb2.SiLAFramework_pb2 import Duration as SilaDuration
 
 
-class Duration(MessageMappable):
-    native_type = timedelta
-    message_type: Type[SilaDuration]
-
+class Duration(MessageMappable[SilaDuration, timedelta]):
     def __init__(self, silaframework_pb2_module: SiLAFramework_pb2):
         self.message_type = silaframework_pb2_module.Duration
 
