@@ -1,12 +1,16 @@
-from typing import Optional
+from typing import Generic, Optional, TypeVar
 
 from sila2.framework.abc.composite_message_mappable import CompositeMessageMappable
 from sila2.framework.command.command import Command
 from sila2.framework.command.intermediate_response import IntermediateResponse
 from sila2.framework.utils import xpath_sila
 
+ParametersNamedTuple = TypeVar("ParametersNamedTuple")
+IntermediateResponsesNamedTuple = TypeVar("IntermediateResponsesNamedTuple")
+ResponsesNamedTuple = TypeVar("ResponsesNamedTuple")
 
-class ObservableCommand(Command):
+
+class ObservableCommand(Command, Generic[ParametersNamedTuple, IntermediateResponsesNamedTuple, ResponsesNamedTuple]):
     """Represents an observable command"""
 
     intermediate_responses: Optional[CompositeMessageMappable[IntermediateResponse]]
