@@ -1,40 +1,43 @@
 from __future__ import annotations
 
+import math
 from abc import ABC
-from datetime import date, datetime, time, timezone
-from typing import Any, Callable, Tuple, Union
+from datetime import datetime, time
+from typing import Callable, TypeVar, Union
 
 from sila2.framework.abc.constraint import Constraint
-from sila2.framework.data_types.date import Date
+from sila2.framework.data_types.date import Date, SilaDateType
 from sila2.framework.data_types.integer import Integer
 from sila2.framework.data_types.real import Real
 from sila2.framework.data_types.string import String
 from sila2.framework.data_types.time import Time
 from sila2.framework.data_types.timestamp import Timestamp
 
+T = TypeVar("T", bound=Union[str, int, float, SilaDateType, time, datetime])
+ComparableType = Union[str, int, float, datetime]
 
-class ComparisonConstraint(Constraint, ABC):
-    comparison_operator: Callable[[Any, Any], bool]
+
+class ComparisonConstraint(Constraint[T], ABC):
+    comparison_operator: Callable[[T, T], bool]
     base_type: Union[String, Integer, Real, Date, Time, Timestamp]
-    parsed_value: Union[str, int, float, datetime]
-    value: str
+    reference_value: ComparableType
+    value_from_xml: str
 
     def __init__(
         self,
         base_type: Union[String, Integer, Real, Date, Time, Timestamp],
-        comparison_operator: Callable[[Any, Any], bool],
-        value: str,
+        comparison_operator: Callable[[T, T], bool],
+        value_from_xml: str,
     ):
         self.base_type = base_type
         self.comparison_operator = comparison_operator
-        self.value = value
-        self.parsed_value = self._parse_value_from_string(value)
+        self.value_from_xml = value_from_xml
+        self.reference_value = self._parse_value_from_string(value_from_xml)
 
-    def validate(self, value: Union[str, int, float, Tuple[date, timezone], time, datetime]):
-        parsed_value = self._convert_value_for_comparison(value)
-        return self.comparison_operator(self.parsed_value, parsed_value)
+    def validate(self, value: T) -> bool:
+        return self.comparison_operator(self.reference_value, self._convert_value_for_comparison(value))
 
-    def _convert_value_for_comparison(self, value: Union[str, int, float, Tuple[date, timezone], time, datetime]):
+    def _convert_value_for_comparison(self, value: T) -> ComparableType:
         if isinstance(self.base_type, (String, Integer, Real, Timestamp)):
             return value
         if isinstance(self.base_type, Date):
@@ -53,18 +56,15 @@ class ComparisonConstraint(Constraint, ABC):
         else:
             raise NotImplementedError  # should never happen
 
-    def _parse_value_from_string(self, value: str) -> Union[str, int, float, datetime]:
+    def _parse_value_from_string(self, value: str) -> ComparableType:
         if isinstance(self.base_type, String):
             return value
         if isinstance(self.base_type, Integer):
-            from sila2.framework.constraints.maximal_exclusive import MaximalExclusive
-            from sila2.framework.constraints.maximal_inclusive import MaximalInclusive
-            from sila2.framework.constraints.minimal_exclusive import MinimalExclusive
-            from sila2.framework.constraints.minimal_inclusive import MinimalInclusive
-
-            if isinstance(self, (MaximalExclusive, MaximalInclusive, MinimalExclusive, MinimalInclusive)):
-                return float(value)
-            return int(value)
+            # scientific notation like 3e4 for 30000 is allowed for integers
+            parsed_value = float(value)
+            if not math.isfinite(parsed_value):
+                raise ValueError(f"Integer values must be finite, got {value}")  # should never happen
+            return parsed_value
         if isinstance(self.base_type, Real):
             return float(value)
         if isinstance(self.base_type, Date):
@@ -80,5 +80,5 @@ class ComparisonConstraint(Constraint, ABC):
 
     def __repr__(self) -> str:
         if isinstance(self.base_type, (Integer, Real)):
-            return f"{self.__class__.__name__}({self.parsed_value})"
-        return f"{self.__class__.__name__}({self.value!r})"
+            return f"{self.__class__.__name__}({self.reference_value})"
+        return f"{self.__class__.__name__}({self.value_from_xml!r})"
