@@ -2,16 +2,14 @@ from __future__ import annotations
 
 import json
 import os
+import warnings
 from enum import Enum
 from os.path import join
-from typing import TYPE_CHECKING, Any, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Optional, TypeVar, Union
 from urllib.request import urlopen
 
-import jsonschema
-import xmlschema
 from lxml import etree
 from lxml.etree import XMLParser
-from xmlschema import XMLSchemaValidationError
 
 from sila2 import resource_dir
 from sila2.framework.abc.constraint import Constraint
@@ -21,6 +19,23 @@ if TYPE_CHECKING:
     from sila2.framework.abc.data_type import DataType
     from sila2.framework.feature import Feature
 
+JSONSCHEMA_INSTALLED = False
+try:
+    import jsonschema
+
+    JSONSCHEMA_INSTALLED = True
+except ImportError:
+    pass
+
+XMLSCHEMA_INSTALLED = False
+try:
+    import xmlschema
+    from xmlschema import XMLSchemaValidationError
+
+    XMLSCHEMA_INSTALLED = True
+except ImportError:
+    pass
+
 
 T = TypeVar("T", bound=Union[str, bytes])
 
@@ -29,15 +44,24 @@ class Schema(Constraint[T]):
     schema_type: SchemaType
     source_type: SchemaSourceType
     source: str
-    schema: Union[Any, xmlschema.XMLSchema, etree.XMLSchema]
+    schema: Optional[Union[Any, xmlschema.XMLSchema, etree.XMLSchema]]
+    schema_lib_installed: bool
 
     def __init__(self, schema_type: SchemaType, source_type: SchemaSourceType, source: str):
+        if schema_type is SchemaType.Xml:
+            self.schema_lib_installed = XMLSCHEMA_INSTALLED
+        else:
+            self.schema_lib_installed = JSONSCHEMA_INSTALLED
+
         self.schema_type = schema_type
         self.source_type = source_type
         self.source = source
         self.schema = self.get_schema()
 
     def validate(self, content: T) -> bool:
+        if self.schema is None:
+            return True
+
         if isinstance(self.schema, etree.XMLSchema):
             if isinstance(content, str):
                 content = content.encode("utf-8")
@@ -71,7 +95,7 @@ class Schema(Constraint[T]):
         schema_value = schema_node.text
         return cls(_type, source_type, schema_value)
 
-    def get_schema(self) -> Union[Any, xmlschema.XMLSchema]:
+    def get_schema(self) -> Optional[Union[Any, xmlschema.XMLSchema]]:
         # XML
         if self.schema_type == SchemaType.Xml:
             if self.source_type == SchemaSourceType.Url:
@@ -79,11 +103,23 @@ class Schema(Constraint[T]):
                     join(resource_dir, "xsd")
                 ):
                     return etree.XMLSchema(etree.parse(join(resource_dir, "xsd", self.source.split("/")[-1])))
+
+                if not XMLSCHEMA_INSTALLED:
+                    warnings.warn(
+                        "Found XML Schema constraint, but `xmlschema` is not installed. Constraint will be ignored."
+                    )
+                    return None
                 return xmlschema.XMLSchema(self.source)
             else:
                 return etree.XMLSchema(etree.fromstring(self.source.encode("utf-8")))
 
         # JSON
+        if not JSONSCHEMA_INSTALLED:
+            warnings.warn(
+                "Found JSON Schema constraint, but `jsonschema` is not installed. Constraint will be ignored."
+            )
+            return None
+
         if self.source_type == SchemaSourceType.Inline:
             schema_str = self.source
         else:
