@@ -1,7 +1,9 @@
 from __future__ import annotations
 
+import ipaddress
 import os.path
 import re
+import socket
 import sys
 import tempfile
 from base64 import standard_b64encode
@@ -10,7 +12,7 @@ from contextlib import contextmanager
 from importlib import import_module
 from os.path import abspath, join
 from types import ModuleType
-from typing import TYPE_CHECKING, Generator, NoReturn, Tuple, Union
+from typing import TYPE_CHECKING, Generator, List, NoReturn, Tuple, Union
 
 import grpc
 from grpc_tools import protoc
@@ -181,10 +183,34 @@ def raise_as_rpc_error(error: Union[SilaError, BinaryTransferError], context: gr
     )
 
 
-def consume_generator(generator: Generator):
+def consume_generator(generator: Generator) -> None:
     """
     Exhausts a generator and discards its content
 
     From Itertools Recipes: https://docs.python.org/3/library/itertools.html#itertools-recipes
     """
     deque(generator, maxlen=0)
+
+
+def resolve_host_to_ip_addresses(host: str) -> List[str]:
+    """
+    Convert a given host (name or address) to the associated ip address(es)
+
+    Currently,
+    """
+    if host == "0.0.0.0":
+        # host is all local IPv4 addresses
+        return [
+            socket.gethostbyname(socket.gethostname()),
+            socket.gethostbyname("localhost"),
+        ]
+
+    try:
+        # host is IP address
+        return [ipaddress.ip_address(host).exploded]
+    except ValueError:
+        try:
+            # host is a valid hostname
+            return [socket.gethostbyname(host)]
+        except socket.gaierror as e:
+            raise ValueError(f"Failed to resolve host '{host}': {e.strerror}")
