@@ -349,7 +349,14 @@ class FeatureImplementationServicer:
                     InvalidMetadata(f"Did not receive required metadata '{expected_meta_fqi}'"), context
                 )
 
-        return MetadataDict(parent_server=self.parent_server, base_dict=received_metadata)
+        metadata_to_forward = {}
+        for received_metadata_fqi, metadata_item in received_metadata.items():
+            if received_metadata_fqi not in expected_metadata:
+                self.logger.warning(f"Received unexpected metadata {received_metadata_fqi}, ignoring")
+            else:
+                metadata_to_forward[received_metadata_fqi] = metadata_item
+
+        return MetadataDict(parent_server=self.parent_server, base_dict=metadata_to_forward)
 
     def __raise_as_rpc_error(self, error: SilaError, context: grpc.ServicerContext) -> NoReturn:
         self.logger.error(f"Raising exception as RpcError: {error!r}")
